@@ -48,33 +48,41 @@ LOG_FILE_NAME = 'whatap-hook.log'
 
 isFrappeCommands = "get-frappe-commands" in sys.argv if hasattr(sys, "argv") else False
 
-def read_ignore_whatap_stdout():
-    ignore_whatap_stdout = 'false'
+def preview_whatap_conf(option_name:str):
     home = os.environ.get('WHATAP_HOME', '.')
     whatap_config = os.path.join(home, 'whatap.conf')
+
+
+    """
+    현재 preview_whatap_conf 를 사용중인 옵션
+    - ignore_whatap_stdout (False)
+    - standalone_enabled (False)
+    - open_file_descriptor_enabled (False)
+    """
+    value = 'false'
     try:
         with open(whatap_config) as f:
             for raw in f:
                 line = raw.strip()
                 if not line or line.startswith('#'):
                     continue
-                if line.startswith('ignore_whatap_stdout'):
+                if line.startswith(option_name):
                     parts = line.split('=', 1)
                     if len(parts) == 2:
-                        ignore_whatap_stdout = parts[1].strip()
+                        value = parts[1].strip()
                     break
-        return ignore_whatap_stdout
+        return value
 
     except FileNotFoundError:
-        return ignore_whatap_stdout
+        return value
 
     except Exception as e:
         print(f'WHATAP: config parse error ({e!r})')
-        return ignore_whatap_stdout
+        return value
 
 
 
-ignore_whatap_stdout = read_ignore_whatap_stdout()
+ignore_whatap_stdout = preview_whatap_conf("ignore_whatap_stdout")
 
 
 
@@ -329,6 +337,14 @@ def hooks(home):
                                                       'trace',
                                                       'mod',
                                                       key)}
+
+            if conf.standalone_enabled:
+                if conf.standalone_type == 'multiple-transaction':
+                    from whatap.trace.mod.standalone.multiple import instrument_standalone_multiple
+                    instrument_standalone_multiple()
+                else:
+                    from whatap.trace.mod.standalone.single import instrument_standalone_single
+                    instrument_standalone_single()
         
         except Exception as e:
             logging.debug(e, extra={'id': 'PLUGIN ERROR'})
@@ -354,9 +370,11 @@ def agent():
     if write_file(home, home.lower(), whatap_home):
         os.environ['WHATAP_HOME'] = whatap_home
         
-        # t = threading.Thread(target=go)
-        # t.setDaemon(True)
-        # t.start()
+        whatap_code_start = preview_whatap_conf("whatap_code_start")
+        if whatap_code_start == 'true':
+            t = threading.Thread(target=go)
+            t.setDaemon(True)
+            t.start()
         config(home)
 
 ARCH = {
@@ -435,9 +453,9 @@ def go(batch=False, opts={}):
 
 import signal
 
-from whatap.trace.mod.application_wsgi import interceptor, start_interceptor, \
+from whatap.trace.mod.application.wsgi import interceptor, start_interceptor, \
     end_interceptor, trace_handler, interceptor_step_error
-from whatap.trace.mod.application_fastapi import interceptor_error_log
+from whatap.trace.mod.application.fastapi import interceptor_error_log
 from whatap.trace.trace_context import TraceContext, TraceContextManager
 
 def register_app(fn):
