@@ -403,11 +403,17 @@ def interceptor_db_con(fn, db_info, *args, **kwargs):
         kwargs = dict(
             x.split('=') for x in re.sub(r'\s*=\s*', '=', args[0]).split())
 
-    text = '{}://'.format(db_info.get('type'))
-    text += kwargs.get('user' , '')
-    text += "@"
-    text += kwargs.get('host', kwargs.get('dsn', ''))
-    text += '/'
+    db_type = db_info.get('type')
+
+    if db_type == "sqlite":
+        text = "sqlite:"
+    else:
+        text = '{}://'.format(db_type)
+        text += kwargs.get('user', '')
+        text += "@"
+        text += kwargs.get('host', kwargs.get('dsn', ''))
+        text += '/'
+
     text += kwargs.get('database', kwargs.get('db', kwargs.get('dbname', '')))
     ctx.active_dbc = text
     ctx.lctx['dbc'] = text
@@ -445,14 +451,58 @@ def addQuoteList(arg_list):
     return tuple(quoted_list)
 
 def neo4jQuery(query,paremeter):
-    transformed_query = query
+    neo4j_query = query
 
     for key, value in paremeter.items():
         placeholder = f"${key}"
         replacement = f"'{str(value)}'"
-        transformed_query = transformed_query.replace(placeholder, replacement)
+        neo4j_query = neo4j_query.replace(placeholder, replacement)
 
-    return transformed_query
+    return neo4j_query
+
+def sqliteQuery(query, paremeter):
+    sqlite_query = query
+
+    def quote(v):
+        if v is None: return "NULL"
+        if isinstance(v, (bytes, bytearray)): return "X'" + v.hex() + "'"
+        return "'" + str(v).replace("'", "''") + "'"
+
+    # 이름 기반: :name / @name / $name (단일 세트)
+    if isinstance(paremeter, dict):
+        for pfx in (':', '@', '$'):
+            for k, v in paremeter.items():
+                sqlite_query = sqlite_query.replace(f"{pfx}{k}", quote(v))
+        return sqlite_query
+
+    # 포지셔널 + executemany 분기
+    if isinstance(paremeter, (list, tuple)):
+        # ── executemany: [tuple|dict, ...] ──
+        if isinstance(paremeter, list) and paremeter and isinstance(paremeter[0], (tuple, dict)):
+            stmts = []
+            for params in paremeter:
+                sqlite_query = query
+                if isinstance(params, dict):
+                    for pfx in (':', '@', '$'):
+                        for k, v in params.items():
+                            sqlite_query = sqlite_query.replace(f"{pfx}{k}", quote(v))
+                else:  # tuple
+                    for i, v in enumerate(params, 1):
+                        sqlite_query = sqlite_query.replace(f"?{i}", quote(v))
+                    for v in params:
+                        sqlite_query = sqlite_query.replace('?', quote(v), 1)
+                stmts.append(sqlite_query)
+            return ";\n".join(stmts)
+
+        # ── 단일 포지셔널 세트 (tuple 또는 스칼라 list) ──
+        seq = paremeter if isinstance(paremeter, tuple) else tuple(paremeter)
+        for i, v in enumerate(seq, 1):
+            sqlite_query = sqlite_query.replace(f"?{i}", quote(v))
+        for v in seq:
+            sqlite_query = sqlite_query.replace('?', quote(v), 1)
+        return sqlite_query
+
+    return sqlite_query
 
 def interceptor_db_execute(fn, db_info, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
@@ -466,6 +516,13 @@ def interceptor_db_execute(fn, db_info, *args, **kwargs):
             query = neo4jQuery(args[1], kwargs)
         except Exception as e:
             pass
+
+    elif db_type == "sqlite" and len(args) > 2:
+        try:
+            query = sqliteQuery(args[1],args[2])
+        except Exception as e:
+            pass
+
     else:
         if len(args) > 2 and type(args[2]) == dict and args[2]:
             try:
@@ -486,24 +543,6 @@ def interceptor_db_execute(fn, db_info, *args, **kwargs):
     if not query:
         return fn(*args, **kwargs)
 
-    start_time = DateUtil.nowSystem()
-    ctx.start_time = start_time
-
-    text = '{}://'.format(db_info.get('type'))
-    text += db_info.get('user' , '')
-    text += "@"
-    text += db_info.get('host', db_info.get('dsn', ''))
-    text += '/'
-    text += db_info.get('database', db_info.get('db', db_info.get('dbname', '')))
-    ctx.active_dbc = text
-    ctx.lctx['dbc'] = text
-
-    ctx.active_dbc = 0
-
-    datas = [text]
-    ctx.elapsed = DateUtil.nowSystem() - start_time
-    async_sender.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
-
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
     ctx.active_sqlhash = query
